require 'omniauth'
require 'ebay'

OmniAuth.config.add_camelization 'ebay', 'Ebay'

module OmniAuth
  module Strategies
    class Ebay
      include OmniAuth::Strategy

      args    [
        :passthrough_parameters,
      ]

      option  :passthrough_parameters, {}

      uid     { user.guid }

      info do
        {
          ebay_id:    user.id,
          auth_token: auth_token,
          email:      user.email,
          full_name:  user.name,
          country:    user.country,
        }
      end

      def request_phase
        session = Ebay::Repositories::SessionRepository.create

        redirect session.to_login_url(
                   passthrough_parameters: options.passthrough_parameters)
      end

      private

      def user
        @user ||= Ebay::Repositories::UserRepository.find(
                    username:   request.params['username'],
                    auth_token: auth_token)
      end

      def auth_token
        @auth_token ||= Ebay::Repositories::TokenRepository.create(
                          username: request.params['username'],
                          secret:   request.params['sid'])
      end
    end
  end
end
